.. _spkg_charset_normalizer:

charset_normalizer: The Real First Universal Charset Detector. Open, modern and actively maintained alternative to Chardet.
===========================================================================================================================

Description
-----------

The Real First Universal Charset Detector. Open, modern and actively maintained alternative to Chardet.

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/charset-normalizer/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    3.4.2

version_requirements.txt::

    charset-normalizer

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install charset-normalizer

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i charset_normalizer

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install charset-normalizer

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install python3-charset-normalizer

.. tab:: Gentoo Linux:

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-python/charset_normalizer

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-python-charset-normalizer

.. tab:: Void Linux:

   .. CODE-BLOCK:: bash

       $ sudo xbps-install python3-charset-normalizer


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
